@@ -1,8 +1,6 @@
 use crate::app::{App, Mode};
 use tui::backend::Backend;
 use tui::layout::{Constraint, Direction, Layout};
-use tui::style::{Color, Style};
-use tui::widgets::{Block, Borders, Paragraph};
 use tui::Frame;
 use unicode_width::UnicodeWidthStr;
 
@@ -12,20 +10,21 @@ pub fn draw<B: Backend>(f: &mut Frame<B>, app: &mut App) {
         .margin(2)
         .constraints([Constraint::Length(3), Constraint::Min(1)].as_ref())
         .split(f.size());
-    let command_bar = Paragraph::new(app.command.as_ref())
-        .style(match app.mode {
-            Mode::Normal => Style::default(),
-            Mode::Command => Style::default().fg(Color::Yellow),
-        })
-        .block(Block::default().borders(Borders::ALL).title("Action"));
-    f.render_widget(command_bar, chunks[0]);
-    match app.mode {
+    f.render_widget(app.cmd_line.clone(), chunks[0]);
+    f.render_widget(app.main_widget.clone(), chunks[1]);
+
+    match app.state.mode {
         Mode::Normal => {}
         Mode::Command => f.set_cursor(
-            chunks[0].x + app.command.width() as u16 + 1,
+            chunks[0].x + app.cmd_line.message.width() as u16 + 1,
             chunks[0].y + 1,
         ),
+        Mode::Insert => {
+            let input_lines: Vec<&str> = app.main_widget.get_input().split('\n').collect();
+            f.set_cursor(
+                chunks[1].x + input_lines.last().unwrap_or(&"").width() as u16 + 1,
+                chunks[1].y + input_lines.len() as u16,
+            );
+        }
     }
-
-    f.render_widget(app.main_widget.clone(), chunks[1]);
 }
